# Reference
<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

**Classes**

* [`cockroachdb`](#cockroachdb): Recives parameters from the user and initializes the cockroach::install and cockroach::config
classes.
* [`cockroachdb::client`](#cockroachdbclient): Install the cockroachdb client
* [`cockroachdb::config`](#cockroachdbconfig): This class is called from the cockroachdb class to configure the program.
* [`cockroachdb::install`](#cockroachdbinstall): This class is called from the the cockroachdb class for installation.
* [`cockroachdb::params`](#cockroachdbparams): Default values for cockroachdb module.
* [`cockroachdb::service`](#cockroachdbservice): This class is called from the cockroachdb class to configure the service.

**Tasks**

* [`init`](#init): Initialize a database cluster
* [`node_decommission`](#node_decommission): Decommission a node from the cluster
* [`node_ls`](#node_ls): List nodes in a cluster.
* [`node_status`](#node_status): Check status of a node in the cluster.
* [`quit`](#quit): Stop a node in a cluster.
* [`restart_service`](#restart_service): Restart cockroachdb service
* [`sql`](#sql): Run a sql command on a cluster

## Classes

### cockroachdb

Recives parameters from the user and initializes the cockroach::install and cockroach::config
classes.

#### Parameters

The following parameters are available in the `cockroachdb` class.

##### `servicepath`

Data type: `Optional[Stdlib::Absolutepath]`

Location of where the ".service" file is to be saved.
If the parameter is not defined it will be saved in "/etc/systemd/system".

Default value: $cockroachdb::params::servicepath

##### `workingdirectory`

Data type: `Optional[Stdlib::Absolutepath]`

Location of where the working directory will be created.
If the parameter is not defined it will be created in "/var/lib/cockroach".

Default value: $cockroachdb::params::workingdirectory

##### `dependencies`

Data type: `Optional[Tuple]`

Consists of dependencies 'tar' and 'wget' by default. Failing to include these dependencies while defining
this parameter yourself may result in dependency issues.

Default value: $cockroachdb::params::dependencies

##### `description`

Data type: `Optional[String]`

Cockroachdb node description.

Default value: $cockroachdb::params::description

##### `cache`

Data type: `Optional[String]`

The total size for caches, shared if there are multiple storage devices, noted with a
decimal or '%'.

Default value: $cockroachdb::params::cache

##### `maxsqlmemory`

Data type: `Optional[String]`

The maximum in-memory storage capaciy available to store temprary data for SQL queries.
Noted with a decimal point or '%'.

Default value: $cockroachdb::params::maxsqlmemory

##### `timeoutstopsec`

Data type: `Optional[String]`

Configures the time to wait for each ExecStop command for systemd.

Default value: $cockroachdb::params::timeoutstopsec

##### `restart`

Data type: `Optional[String]`

Defines when the service is to be restarted. Configured with always by default
and will restart on every restart setting and exit cause.

Default value: $cockroachdb::params::restart

##### `restartsec`

Data type: `Optional[String]`

Defines the time to sleep before restarting the service.

Default value: $cockroachdb::params::restartsec

##### `standardoutput`

Data type: `Optional[String]`

Controls where the file descriptor 1 (STDOUT) of the executed processes is connected to.

Default value: $cockroachdb::params::standardoutput

##### `standarderror`

Data type: `Optional[String]`

Controls where the file descriptor 2 (STDERR) of the executed process is connected to.

Default value: $cockroachdb::params::standarderror

##### `syslogidentifier`

Data type: `Optional[String]`

Sets the process name ("syslog tag") to prefix log lines sent to the logging system
or the kernel log buffer.

Default value: $cockroachdb::params::syslogidentifier

##### `user`

Data type: `Optional[String]`

Sets the user/group that the processes are executed as.

Default value: $cockroachdb::params::user

##### `node1ip`

Data type: `String`

Sets the ip-address for node one. Set to localhost when in single node mode.

Default value: $cockroachdb::params::node1ip

##### `node2ip`

Data type: `Optional[String]`

Sets the ip-address for node two. Skip for single node mode.

Default value: $cockroachdb::params::node2ip

##### `node3ip`

Data type: `Optional[String]`

Sets the ip-address for node three. Skip for single node mode.

Default value: $cockroachdb::params::node3ip

##### `install_path`

Data type: `Optional[Stdlib::Absolutepath]`

Location where the program binary file is to be located.

Default value: $cockroachdb::params::install_path

##### `package_name`

Data type: `Optional[String]`

Name of the package to install.

Default value: $cockroachdb::params::package_name

##### `package_ensure`

Data type: `String`

Version number and linux distribution name.

Default value: $cockroachdb::params::package_ensure

##### `repository_url`

Data type: `Optional[String]`

Base repository URL.

Default value: $cockroachdb::params::repository_url

##### `archive_name`

Data type: `Optional[String]`

Archive path of the binary file in the base repository.

Default value: $cockroachdb::params::archive_name

##### `cockroachdb_package_source`

Data type: `Optional[String]`

Full binary package source.

Default value: $cockroachdb::params::cockroachdb_package_source

##### `additional_params`

Data type: `Optional[String]`

Additional params and flags to pass to cockroachdb on startup. Must be provided as fully valid cockroachdb flags.

Default value: $cockroachdb::params::additional_params

##### `secure_mode`

Data type: `Boolean`

If cockroachdb secure mode is enabled or not. Currently only supports insecure mode.

Default value: $cockroachdb::params::secure_mode

##### `locality`

Data type: `Optional[Array[String, 1]]`

Array of Hashes containing locality information for nodes.

Default value: $cockroachdb::params::locality

##### `certs_dir`

Data type: `Optional[Stdlib::Absolutepath]`

The directory where CockroachDB can find certificates.

Default value: $cockroachdb::params::certs_dir

##### `dns_mode`

Data type: `Optional[Enum['hostname', 'fqdn', 'ipaddress', 'custom']]`

Use FQDN, hostnames, IPs or custom facts to identify nodes.

Default value: $cockroachdb::params::dns_mode

##### `dns_mode_custom`

Data type: `Optional[String]`

Custom fact used to identify nodes. Can be any valid facter fact, like custom facts.

Default value: $cockroachdb::params::dns_mode_custom

### cockroachdb::client

Install the cockroachdb client

#### Examples

##### 

```puppet
include cockroachdb::client
```

#### Parameters

The following parameters are available in the `cockroachdb::client` class.

##### `workingdirectory`

Data type: `Optional[Stdlib::Absolutepath]`

Location of where the working directory will be created.
If the parameter is not defined it will be created in "/var/lib/cockroach".

Default value: $cockroachdb::params::workingdirectory

##### `dependencies`

Data type: `Optional[Tuple]`

Consists of dependencies 'tar' and 'wget' by default. Failing to include these dependencies while defining
this parameter yourself may result in dependency issues.

Default value: $cockroachdb::params::dependencies

##### `install_path`

Data type: `Optional[Stdlib::Absolutepath]`

Location where the program binary file is to be located.

Default value: $cockroachdb::params::install_path

##### `package_name`

Data type: `Optional[String]`

Name of the package to install.

Default value: $cockroachdb::params::package_name

##### `package_ensure`

Data type: `String`

Version number and linux distribution name.

Default value: $cockroachdb::params::package_ensure

##### `repository_url`

Data type: `Optional[String]`

Base repository URL.

Default value: $cockroachdb::params::repository_url

##### `archive_name`

Data type: `Optional[String]`

Archive path of the binary file in the base repository.

Default value: $cockroachdb::params::archive_name

##### `cockroachdb_package_source`

Data type: `Optional[String]`

Full binary package source.

Default value: $cockroachdb::params::cockroachdb_package_source

### cockroachdb::config

This class is called from the cockroachdb class to configure the program.

### cockroachdb::install

This class is called from the the cockroachdb class for installation.

### cockroachdb::params

Default values for cockroachdb module.

### cockroachdb::service

This class is called from the cockroachdb class to configure the service.

## Tasks

### init

Initialize a database cluster

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

### node_decommission

Decommission a node from the cluster

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

##### `wait`

Data type: `Optional[Enum[all,none]]`

When to return to the client. Possible values: all, none.

### node_ls

List nodes in a cluster.

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

##### `format`

Data type: `Optional[Enum[tsv,csv,table,records,sql,html]]`

How to display table rows printed to the standard output. Possible values: tsv, csv, table, records, sql, html.

##### `timeout`

Data type: `Optional[Pattern[/^[0-9]{1,}(s|m|h)$/]]`

Set the duration of time that the subcommand is allowed to run before it returns an error and prints partial information. The timeout is specified with a suffix of s for seconds, m for minutes, and h for hours. If this flag is not set, the subcommand may hang.

### node_status

Check status of a node in the cluster.

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

##### `format`

Data type: `Optional[Enum[tsv,csv,table,records,sql,html]]`

How to display table rows printed to the standard output. Possible values: tsv, csv, table, records, sql, html.

##### `timeout`

Data type: `Optional[Pattern[/^[0-9]{1,}(s|m|h)$/]]`

Set the duration of time that the subcommand is allowed to run before it returns an error and prints partial information. The timeout is specified with a suffix of s for seconds, m for minutes, and h for hours. If this flag is not set, the subcommand may hang.

##### `all`

Data type: `Optional[Boolean]`

Show all node details.

##### `decommission`

Data type: `Optional[Boolean]`

Show node decommissioning details.

##### `ranges`

Data type: `Optional[Boolean]`

Show node details for ranges and replicas.

##### `stats`

Data type: `Optional[Boolean]`

Show node disk usage details.

### quit

Stop a node in a cluster.

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

##### `decommission`

Data type: `Optional[Boolean]`

If specified, the node will be permanently removed instead of temporarily stopped.

### restart_service

Restart cockroachdb service

**Supports noop?** false

### sql

Run a sql command on a cluster

**Supports noop?** false

#### Parameters

##### `host`

Data type: `Optional[String[1]]`

The server host and port number to connect to. This can be the address of any node in the cluster.

##### `port`

Data type: `Optional[Integer[1]]`

The server port to connect to. Note: The port number can also be specified via --host.

##### `user`

Data type: `Optional[String[1]]`

The SQL user that will own the client session.

##### `insecure`

Data type: `Optional[Boolean]`

Use an insecure connection.

##### `certs_dir`

Data type: `Optional[String[1]]`

The path to the certificate directory containing the CA and client certificates and client key.

##### `url`

Data type: `Optional[String[1]]`

A connection URL to use instead of the other arguments.

##### `database`

Data type: `Optional[String[1]]`

A database name to use as current database in the newly created session.

##### `echo_sql`

Data type: `Optional[String[1]]`

Reveal the SQL statements sent implicitly by the command-line utility.

##### `execute`

Data type: `String[1]`

Execute SQL statements directly from the command line, without opening a shell. Non-optional, to prevent shell from opening

##### `format`

Data type: `Optional[Enum[tsv,csv,table,raw,records,sql,html]]`

How to display table rows printed to the standard output. Possible values: tsv, csv, table, raw, records, sql, html.

##### `safe_updates`

Data type: `Optional[Boolean]`

Disallow potentially unsafe SQL statements.

##### `set`

Data type: `Optional[String[1]]`

Set a client-side option before executing SQL statements from the command line via --execute.

